summaryrefslogtreecommitdiffstats
path: root/usr.sbin/ppp/physical.h
diff options
context:
space:
mode:
authorbrian <brian@FreeBSD.org>2000-03-14 01:46:09 +0000
committerbrian <brian@FreeBSD.org>2000-03-14 01:46:09 +0000
commit9c5b52bb1ff54c68085f3d991416208f25de7639 (patch)
treedbe961365e18f19df00ee52df51b62d05741ec40 /usr.sbin/ppp/physical.h
parentfe41605fe0c0e256c26622b4c8e5edf23f72d7c7 (diff)
downloadFreeBSD-src-9c5b52bb1ff54c68085f3d991416208f25de7639.zip
FreeBSD-src-9c5b52bb1ff54c68085f3d991416208f25de7639.tar.gz
To avoid namespace polution in NetBSD:
``struct descriptor'' -> ``struct fdescriptor''
Diffstat (limited to 'usr.sbin/ppp/physical.h')
-rw-r--r--usr.sbin/ppp/physical.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/usr.sbin/ppp/physical.h b/usr.sbin/ppp/physical.h
index c5aaea8..9946eaf 100644
--- a/usr.sbin/ppp/physical.h
+++ b/usr.sbin/ppp/physical.h
@@ -73,11 +73,11 @@ struct device {
struct physical {
struct link link;
- struct descriptor desc;
+ struct fdescriptor desc;
int type; /* What sort of PHYS_* link are we ? */
struct async async; /* Our async state */
struct hdlc hdlc; /* Our hdlc state */
- int fd; /* File descriptor for this device */
+ int fd; /* File fdescriptor for this device */
struct mbuf *out; /* mbuf that suffered a short write */
int connect_count;
struct datalink *dl; /* my owner */
@@ -148,10 +148,10 @@ extern void physical_SetDevice(struct physical *, const char *);
extern ssize_t physical_Read(struct physical *, void *, size_t);
extern ssize_t physical_Write(struct physical *, const void *, size_t);
-extern int physical_doUpdateSet(struct descriptor *, fd_set *, fd_set *,
+extern int physical_doUpdateSet(struct fdescriptor *, fd_set *, fd_set *,
fd_set *, int *, int);
-extern int physical_IsSet(struct descriptor *, const fd_set *);
-extern void physical_DescriptorRead(struct descriptor *, struct bundle *,
+extern int physical_IsSet(struct fdescriptor *, const fd_set *);
+extern void physical_DescriptorRead(struct fdescriptor *, struct bundle *,
const fd_set *);
extern void physical_Login(struct physical *, const char *);
extern int physical_RemoveFromSet(struct physical *, fd_set *, fd_set *,
OpenPOWER on IntegriCloud